==> eiffelstudio-18.11.10.2592.tar: F_code/C12/dt571.c <==
/*
 * Code for class DT_WEEK_DAY_FROM_MONDAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt571.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_WEEK_DAY_FROM_MONDAY}.monday_code */
EIF_INTEGER_32 F1257_10828 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.tuesday_code */
EIF_INTEGER_32 F1257_10829 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.wednesday_code */
EIF_INTEGER_32 F1257_10830 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.thursday_code */
EIF_INTEGER_32 F1257_10831 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.friday_code */
EIF_INTEGER_32 F1257_10832 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.saturday_code */
EIF_INTEGER_32 F1257_10833 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.sunday_code */
EIF_INTEGER_32 F1257_10834 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.days_in_week */
EIF_INTEGER_32 F1257_10774 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.same_week_day */
EIF_BOOLEAN F1257_11016 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOSCF(8018,F1105_8018,(Current));
	tb1 = F27_205(RTCW(tr1), Current, arg1);
	if (tb1) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_0_);
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
	} else {
		switch (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_)) {
			case 1L:
				Result = F1255_10987(RTCW(arg1));
				break;
			case 2L:
				Result = F1255_10988(RTCW(arg1));
				break;
			case 3L:
				Result = F1255_10989(RTCW(arg1));
				break;
			case 4L:
				Result = F1255_10990(RTCW(arg1));
				break;
			case 5L:
				Result = F1255_10991(RTCW(arg1));
				break;
			case 6L:
				Result = F1255_10992(RTCW(arg1));
				break;
			case 7L:
				Result = F1255_10993(RTCW(arg1));
				break;
			default:
				RTEC(EN_WHEN);
		}
	}
	RTLE;
	return Result;
}

/* {DT_WEEK_DAY_FROM_MONDAY}.as_week_day_from_sunday */
EIF_REFERENCE F1257_11017 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if (F1255_10993(Current)) {
		Result = RTOSCF(10807,F1245_10807,(RTCV(RTOSCF(886,F74_886,(Current)))));
	} else {
		tr1 = RTOSCF(886,F74_886,(Current));
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		Result = F1245_10808(RTCW(tr1), (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
	}
	RTLE;
	return Result;
}

/* {DT_WEEK_DAY_FROM_MONDAY}.as_week_day_from_monday */
EIF_REFERENCE F1257_11018 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) Current;
}

void EIF_Minit571 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C12/dt571.c <==
/*
 * Code for class DT_WEEK_DAY_FROM_MONDAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt571.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_WEEK_DAY_FROM_MONDAY}.monday_code */
EIF_INTEGER_32 F1263_10838 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.tuesday_code */
EIF_INTEGER_32 F1263_10839 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.wednesday_code */
EIF_INTEGER_32 F1263_10840 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.thursday_code */
EIF_INTEGER_32 F1263_10841 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.friday_code */
EIF_INTEGER_32 F1263_10842 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.saturday_code */
EIF_INTEGER_32 F1263_10843 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.sunday_code */
EIF_INTEGER_32 F1263_10844 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.days_in_week */
EIF_INTEGER_32 F1263_10784 (EIF_REFERENCE Current)
{
	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
}

/* {DT_WEEK_DAY_FROM_MONDAY}.same_week_day */
EIF_BOOLEAN F1263_11049 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOSCF(8049,F1105_8049, (Current));
	tb1 = F27_205(RTCW(tr1), Current, arg1);
	if (tb1) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_0_);
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
	} else {
		switch (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_)) {
			case 1L:
				Result = F1261_11020(RTCW(arg1));
				break;
			case 2L:
				Result = F1261_11021(RTCW(arg1));
				break;
			case 3L:
				Result = F1261_11022(RTCW(arg1));
				break;
			case 4L:
				Result = F1261_11023(RTCW(arg1));
				break;
			case 5L:
				Result = F1261_11024(RTCW(arg1));
				break;
			case 6L:
				Result = F1261_11025(RTCW(arg1));
				break;
			case 7L:
				Result = F1261_11026(RTCW(arg1));
				break;
			default:
				RTEC(EN_WHEN);
		}
	}
	RTLE;
	return Result;
}

/* {DT_WEEK_DAY_FROM_MONDAY}.as_week_day_from_sunday */
EIF_REFERENCE F1263_11050 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if (F1261_11026(Current)) {
		Result = RTOSCF(10817,F1250_10817, (RTCV(RTOSCF(866,F71_866, (Current)))));
	} else {
		tr1 = RTOSCF(866,F71_866, (Current));
		Result = F1250_10818(RTCW(tr1), (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) + ((EIF_INTEGER_32) 1L)));
	}
	RTLE;
	return Result;
}

/* {DT_WEEK_DAY_FROM_MONDAY}.as_week_day_from_monday */
EIF_REFERENCE F1263_11051 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) Current;
}

void EIF_Minit571 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
